==> spip_2.0.10.orig.tar.gz: spip-2.0.10.orig/ecrire/lang/public_es.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Portada del sitio',
'articles' => 'Art&iacute;culos',
'articles_auteur' => 'Art&iacute;culos de esta autora o autor',
'articles_populaires' => 'Los art&iacute;culos m&aacute;s populares',
'articles_rubrique' => 'Art&iacute;culos de esta secci&oacute;n',
'aucun_article' => 'No hay ning&uacute;n art&iacute;culo en esta direcci&oacute;n ',
'aucun_auteur' => 'No hay autor ni autora en esta direcci&oacute;n ',
'aucun_site' => 'No hay ning&uacute;n sitio en esta direcci&oacute;n',
'aucune_breve' => 'No hay ninguna breve en esta direcci&oacute;n',
'aucune_rubrique' => 'No hay ninguna secci&oacute;n en esta direcci&oacute;n',
'autres' => 'Otros',
'autres_breves' => 'Otros breves',
'autres_groupes_mots_clefs' => 'Otros grupos de palabras clave',
'autres_sites' => 'Otros sitios',

// B
'bonjour' => 'Hola',
'breves' => 'Breves',

// C
'commenter_site' => 'Comentar este sitio',
'copie_document_impossible' => 'Imposible copiar el documento',

// D
'date' => 'Fecha',
'dernier_ajout' => '&Uacute;ltima actualizaci&oacute;n',
'dernieres_breves' => '&Uacute;ltimos breves',
'derniers_articles' => '&Uacute;ltimos art&iacute;culos',
'derniers_commentaires' => '&Uacute;ltimos comentarios',
'derniers_messages_forum' => '&Uacute;ltimos mensajes publicados en los foros',
'documents_interdits_forum' => 'Documentos prohibidos en el foro',

// E
'edition_mode_texte' => 'Edici&oacute;n en modo texto de',
'en_reponse' => 'En respuesta a:',
'en_resume' => 'En resumen',
'envoyer_message' => 'Enviar un mensaje',
'espace_prive' => 'Espacio privado',

// F
'formats_acceptes' => 'Formatos aceptados: @formats@.',
'forum' => 'Foro',

// H
'hierarchie_site' => 'Jerarqu&iacute;a del sitio',

// J
'jours' => 'd&iacute;as',

// L
'lien_connecter' => 'Conectarse',

// M
'meme_auteur' => 'Del mismo autor',
'meme_rubrique' => 'En la misma secci&oacute;n',
'memes_auteurs' => 'De los mismos autores',
'message' => 'Mensaje',
'messages_forum' => 'Mensajes del foro',
'messages_recents' => 'Los mensajes m&aacute;s recientes del foro',
'mots_clefs' => 'Palabras clave',
'mots_clefs_meme_groupe' => 'Palabras claves en el mismo grupo',

// N
'navigation' => 'Navegaci&oacute;n',
'nom' => 'Nombre',
'nouveautes' => 'Las novedades',
'nouveautes_web' => 'Novedades en la web',
'nouveaux_articles' => 'Nuevos art&iacute;culos',
'nouvelles_breves' => 'Nuevas breves',

// P
'page_precedente' => 'P&aacute;gina precedente',
'page_suivante' => 'P&aacute;gina siguiente',
'par_auteur' => 'por ',
'participer_site' => 'Puedes participar en la vida de este sitio y proponer art&iacute;culos inscribi&eacute;ndote aqui. De inmediato recibir&aacute;s un correo electr&oacute;nico con tus claves de acceso al espacio privado del sitio.',
'plan_site' => 'Mapa del sitio',
'popularite' => 'Popularidad',
'poster_message' => 'Publicar un mensaje',
'proposer_site' => 'Proponga un sitio para a&ntilde;adir en esta secci&oacute;n:',

// R
'repondre_article' => 'Comentar este art&iacute;culo',
'repondre_breve' => 'Comentar esta breve',
'repondre_message' => 'Responder este mensaje',
'resultats_recherche' => 'Resultados de la b&uacute;squeda',
'retour_debut_forums' => 'Volver al inicio del foro',
'rubrique' => 'Secci&oacute;n',
'rubriques' => 'Secciones',

// S
'signatures_petition' => 'Firmas',
'site_realise_avec_spip' => 'Sitio desarrollado con SPIP',
'sites_web' => 'Sitios Web',
'sous_rubriques' => 'Subsecci&oacute;n',
'spam' => 'Spam',
'suite' => 'continuar',
'sur_web' => 'Del web',
'syndiquer_rubrique' => 'Sindicar esta secci&oacute;n',
'syndiquer_site' => 'Sindicar el sitio completo',

// T
'texte_lettre_information' => 'Este es el bolet&iacute;n de informaci&oacute;n del sitio',
'texte_lettre_information_2' => 'Este bolet&iacute;n rese&ntilde;a los art&iacute;culos y breves publicados desde ',

// V
'ver_imprimer' => 'Versi&oacute;n para imprimir',
'voir_en_ligne' => 'Ver en l&iacute;nea',
'voir_squelette' => 'ver el esqueleto de esta p&aacute;gina'
);

?>

==> spip_2.1.orig.tar.gz: spip-2.1.orig/ecrire/lang/public_es.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Portada del sitio',
'article' => 'Art&iacute;culo',
'articles' => 'Art&iacute;culos',
'articles_auteur' => 'Art&iacute;culos de esta autora o autor',
'articles_populaires' => 'Los art&iacute;culos m&aacute;s populares',
'articles_rubrique' => 'Art&iacute;culos de esta secci&oacute;n',
'aucun_article' => 'No hay ning&uacute;n art&iacute;culo en esta direcci&oacute;n ',
'aucun_auteur' => 'No hay autor ni autora en esta direcci&oacute;n ',
'aucun_site' => 'No hay ning&uacute;n sitio en esta direcci&oacute;n',
'aucune_breve' => 'No hay ninguna breve en esta direcci&oacute;n',
'aucune_rubrique' => 'No hay ninguna secci&oacute;n en esta direcci&oacute;n',
'auteur' => 'Autor o autora',
'autres' => 'Otros',
'autres_breves' => 'Otros breves',
'autres_groupes_mots_clefs' => 'Otros grupos de palabras clave',
'autres_sites' => 'Otros sitios',

// B
'bonjour' => 'Hola',
'breve' => 'Breve',
'breves' => 'Breves',

// C
'commenter_site' => 'Comentar este sitio',
'copie_document_impossible' => 'Imposible copiar el documento',

// D
'date' => 'Fecha',
'dernier_ajout' => '&Uacute;ltima actualizaci&oacute;n',
'dernieres_breves' => '&Uacute;ltimos breves',
'derniers_articles' => '&Uacute;ltimos art&iacute;culos',
'derniers_commentaires' => '&Uacute;ltimos comentarios',
'derniers_messages_forum' => '&Uacute;ltimos mensajes publicados en los foros',
'documents_interdits_forum' => 'Documentos prohibidos en el foro',

// E
'edition_mode_texte' => 'Edici&oacute;n en modo texto de',
'en_reponse' => 'En respuesta a:',
'en_resume' => 'En resumen',
'envoyer_message' => 'Enviar un mensaje',
'espace_prive' => 'Espacio privado',

// F
'formats_acceptes' => 'Formatos aceptados: @formats@.',
'forum' => 'Foro',

// H
'hierarchie_site' => 'Jerarqu&iacute;a del sitio',

// J
'jours' => 'd&iacute;as',

// L
'lien_connecter' => 'Conectarse',

// M
'meme_auteur' => 'Del mismo autor',
'meme_rubrique' => 'En la misma secci&oacute;n',
'memes_auteurs' => 'De los mismos autores',
'message' => 'Mensaje',
'messages_forum' => 'Mensajes del foro',
'messages_recents' => 'Los mensajes m&aacute;s recientes del foro',
'mots_clef' => 'Palabra clave',
'mots_clefs' => 'Palabras clave',
'mots_clefs_meme_groupe' => 'Palabras claves en el mismo grupo',

// N
'navigation' => 'Navegaci&oacute;n',
'nom' => 'Nombre',
'nouveautes' => 'Las novedades',
'nouveautes_web' => 'Novedades en la web',
'nouveaux_articles' => 'Nuevos art&iacute;culos',
'nouvelles_breves' => 'Nuevas breves',

// P
'page_precedente' => 'P&aacute;gina anterior',
'page_suivante' => 'P&aacute;gina siguiente',
'par_auteur' => 'por ',
'participer_site' => 'Puedes participar en la vida de este sitio y proponer art&iacute;culos inscribi&eacute;ndote aqui. De inmediato recibir&aacute;s un correo electr&oacute;nico con tus claves de acceso al espacio privado del sitio.',
'plan_site' => 'Mapa del sitio',
'popularite' => 'Popularidad',
'poster_message' => 'Publicar un mensaje',
'proposer_site' => 'Proponga un sitio para a&ntilde;adir en esta secci&oacute;n:',

// R
'repondre_article' => 'Comentar este art&iacute;culo',
'repondre_breve' => 'Comentar esta breve',
'repondre_message' => 'Responder este mensaje',
'resultats_recherche' => 'Resultados de la b&uacute;squeda',
'retour_debut_forums' => 'Volver al inicio del foro',
'rubrique' => 'Secci&oacute;n',
'rubriques' => 'Secciones',

// S
'signatures_petition' => 'Firmas',
'site_realise_avec_spip' => 'Sitio desarrollado con SPIP',
'sites_web' => 'Sitios Web',
'sous_rubriques' => 'Subsecci&oacute;n',
'spam' => 'Spam',
'suite' => 'continuar',
'sur_web' => 'Del web',
'syndiquer_rubrique' => 'Sindicar esta secci&oacute;n',
'syndiquer_site' => 'Sindicar el sitio completo',

// T
'texte_lettre_information' => 'Este es el bolet&iacute;n de informaci&oacute;n del sitio',
'texte_lettre_information_2' => 'Este bolet&iacute;n rese&ntilde;a los art&iacute;culos y breves publicados desde ',

// V
'ver_imprimer' => 'Versi&oacute;n para imprimir',
'voir_en_ligne' => 'Ver en l&iacute;nea',
'voir_squelette' => 'ver el esqueleto de esta p&aacute;gina'
);

?>
